@@ -58,6 +58,7 @@ Format placeholders:
         as defined by the 'blocks' and 'charging_character' parameters
     {percent} - the remaining battery percentage (previously '{}')
     {time_remaining} - the remaining time until the battery is empty
+    {power} - the current power consumption in Watts. Not working with acpi.
 
 Color options:
     color_bad: Battery level is below threshold_bad
@@ -82,6 +83,7 @@ discharging
 from re import findall
 from glob import iglob
 
+import itertools
 import math
 import os
 
@@ -250,6 +252,9 @@ class Py3status:
             except IndexError:
                 battery["time_remaining"] = FULLY_CHARGED
 
+            # TODO: Not implemented yet
+            battery["power"] = 0.0
+
             return battery
 
         acpi_list = self.py3.command_output(["acpi", "-b", "-i"]).splitlines()
@@ -289,7 +294,12 @@ class Py3status:
             return raw_values
 
         battery_list = []
-        for path in iglob(os.path.join(self.sys_battery_path, "BAT*")):
+
+        bglobs = ["BAT*", "*bat*"]
+        path_its = itertools.chain(
+            *[iglob(os.path.join(self.sys_battery_path, bglob)) for bglob in bglobs]
+        )
+        for path in path_its:
             r = _parse_battery_info(path)
 
             capacity = r.get(
@@ -302,6 +312,8 @@ class Py3status:
             remaining_energy = r.get(
                 "POWER_SUPPLY_ENERGY_NOW", r.get("POWER_SUPPLY_CHARGE_NOW")
             )
+            current_now = r.get("POWER_SUPPLY_CURRENT_NOW", 0)
+            voltage_now = r.get("POWER_SUPPLY_VOLTAGE_NOW", 0)
 
             battery = {}
             battery["capacity"] = capacity
@@ -319,6 +331,8 @@ class Py3status:
                 # Battery is either full charged or is not discharging
                 battery["time_remaining"] = FULLY_CHARGED
 
+            battery["power"] = current_now * voltage_now / 1e12
+
             battery_list.append(battery)
         return battery_list
 
@@ -337,6 +351,7 @@ class Py3status:
             self.percent_charged = battery["percent_charged"]
             self.charging = battery["charging"]
             self.time_remaining = battery["time_remaining"]
+            self.power_now = battery["power"]
 
         elif self.battery_id == "all":
             total_capacity = sum([battery["capacity"] for battery in battery_list])
@@ -403,6 +418,8 @@ class Py3status:
             else:
                 self.time_remaining = None
 
+            self.power_now = sum([battery["power"] for battery in battery_list])
+
         if self.time_remaining and self.hide_seconds:
             self.time_remaining = self.time_remaining[:-3]
 
@@ -436,6 +453,7 @@ class Py3status:
                 icon=self.icon,
                 percent=self.percent_charged,
                 time_remaining=self.time_remaining,
+                power=self.power_now,
             ),
         )
 
